@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
+** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
 ** Contact: http://www.qt-project.org/legal
 **
 ** This file is part of the QtQuick module of the Qt Toolkit.
@@ -88,7 +88,7 @@ QT_BEGIN_NAMESPACE
     box of the Emitter.
 */
 /*!
-    \qmlproperty bool QtQuick.Particles2::Emitter::emitting
+    \qmlproperty bool QtQuick.Particles2::Emitter::enabled
 
     If set to false, the emitter will cease emissions until it is set to true.
 
