@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
+** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
 ** Contact: http://www.qt-project.org/legal
 **
 ** This file is part of the QtQml module of the Qt Toolkit.
@@ -44,12 +44,21 @@
 
 QT_BEGIN_NAMESPACE
 
+/*!
+    \group qtquick-scenegraph-materials
+    \title Qt Quick Scene Graph Material Classes
+    \brief classes used to define materials in the Qt Quick Scene Graph.
+
+    This page lists the material classes in \l {Qt Quick}'s
+    \l {scene graph}{Qt Quick Scene Graph}.
+ */
 
 /*!
     \class QSGMaterialShader
     \brief The QSGMaterialShader class represents an OpenGL shader program
     in the renderer.
     \inmodule QtQuick
+    \ingroup qtquick-scenegraph-materials
 
     The QSGMaterialShader API is very low-level. A more convenient API, which
     provides almost all the same features, is available through
@@ -479,6 +488,7 @@ static void qt_print_material_count()
     \class QSGMaterialType
     \brief The QSGMaterialType class is used as a unique type token in combination with QSGMaterial.
     \inmodule QtQuick
+    \ingroup qtquick-scenegraph-materials
 
     It serves no purpose outside the QSGMaterial::type() function.
  */
@@ -487,6 +497,7 @@ static void qt_print_material_count()
     \class QSGMaterial
     \brief The QSGMaterial class encapsulates rendering state for a shader program.
     \inmodule QtQuick
+    \ingroup qtquick-scenegraph-materials
 
     The QSGMaterial API is very low-level. A more convenient API, which
     provides almost all the same features, is available through
